@@ -1,9 +1,10 @@
 __all__ = ['is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'to_isbn10', 'to_isbn13', 'get_isbnlike', 'notisbn',
-           'canonical', 'get_canonical_isbn', 'webservice']
+           'canonical', 'get_canonical_isbn', 'webservice', 'editions']
 
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 
 import webservice
 from .isbntoolscore import is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,\
-    canonical, notisbn, get_isbnlike, get_canonical_isbn, mask, meta, info
+    canonical, notisbn, get_isbnlike, get_canonical_isbn, mask, meta, info,\
+    editions
